/*
 * server_ip is the IP address of the ESP8266 module, it will be printed to Serial when the module is connected.
 * The interface shows six buttons and two value fields.
 * The buttons respond if clicked with +,-,F,R,H and N for accelerate, brake, forward, backward, halt and emergency stop.
 * The value fields show motor speed in percent and motor rotation direction.
 */

#include <ESP8266WiFi.h>
#include "WEMOS_Motor.h"
#include <Ticker.h>

#ifndef STASSID
#define STASSID "StEAG_Motor"
#define STAPSK  "NyArVeK1"
#endif


const char* ssid = STASSID;
const char* password = STAPSK;

// Create an instance of the server
// specify the port to listen on as an argument
WiFiServer server(80);

// Create a motor object I2C Address 0x30, Motor A, PWM Freq=1000 Hz
Motor M1(0x30,_MOTOR_A, 1000);  

// Define a variable for motor speed
uint8_t motor_direction = _STOP;

// Define a variable for motor direction
float motor_speed = 0;

// Create a ticker object for working around the shield bug
Ticker ticker_0;

void set_motor() {
  M1.setmotor(motor_direction, motor_speed);
}

void setup() {
  Serial.begin(115200);
  delay(10);
  Serial1.setDebugOutput(true);

  // Connect to WiFi network
  Serial.println();
  Serial.println("Setting up AP");
  
  WiFi.softAP(ssid, password,3);

  IPAddress IP = WiFi.softAPIP();
  Serial.print("AP IP address: ");
  Serial.println(IP);
  WiFi.printDiag(Serial);

  // Start the server
  server.begin();
  Serial.println("Server started");

  ticker_0.attach(1.0, set_motor);
}

void loop() {
  // Check if a client has connected
  WiFiClient client = server.available();
  if (!client) {
    return;
  }
  
  // Wait until the client sends some data
  Serial.println("new client");
  while(!client.available()){
    delay(1);
  }
  
  // Read the first line of the request
/////  String req = client.readStringUntil('\r');
  String req = client.readString(); 
  Serial.println(req);
  client.flush();
  
  // Match the request
  if (req.indexOf("F") != -1)
    motor_direction = _CW;
  if (req.indexOf("R") != -1)
    motor_direction = _CCW;
  if (req.indexOf("+") != -1)
    motor_speed += 5;
  else if (req.indexOf("-") != -1)
    motor_speed -= 5;
  else if (req.indexOf("H") != -1)
    motor_speed = 0;
  else if (req.indexOf("N") != -1)  
    motor_direction = _STOP; 
  else
      Serial.println("Invalid request: " + req);

  client.flush();

  // Prepare the response
  String s = "<!DOCTYPE HTML>\r\n";
  s += "<a href = F><button>FORW</button></a>";
  s += " <a href = +><button>BESCHL.</button></a>";
  s += "<p><a href = H><button>HALT</button></a>";
  s += " <a href = -><button>BREMSEN</button></a>";
  s += "<p><a href = R><button>RCKW</button></a>";
  s += " <a href = N><button>NOTHALT</button></a>";
  s += "<p>Speed: ";
  s += motor_speed;
  s += "<p>Direction: ";
  s += motor_direction;
  s += "</html>\n";

///// show debug values serial:
Serial.print(motor_speed);
Serial.print(" ");
Serial.println(motor_direction);

  // Send the response to the client
  client.print(s);
  delay(1);
  Serial.println("Client disonnected");

  // The client will actually be disconnected 
  // when the function returns and 'client' object is detroyed
}
